雨人 (豆瓣)
Description: 雨人电影简介和剧情介绍,雨人影评、图片、预告片、影讯、论坛、在线购票
Keywords: 雨人,Rain Man,雨人影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.203豆瓣电影Top250

# 雨人 Rain Man (1988)

导演: 巴瑞·莱文森
编剧: 罗纳德·巴斯 / 巴里·莫罗
主演: 达斯汀·霍夫曼 / 汤姆·克鲁斯 / 瓦莱丽亚·戈利诺 / 邦尼·亨特 / 贝丝·格兰特 / 杰克·霍夫曼 / 克里斯·马尔基 / 杰拉尔德·R·莫伦 / 卢辛达·珍妮 / 拉尔夫·塞莫 / 迈克尔·D·罗伯茨 / 罗伊斯·D.阿普勒加特 / 路易莎·莱斯金
类型: 剧情
制片国家/地区: 美国
语言: 英语 / 意大利语
上映日期: 1988-12-16(美国)
片长: 133分钟
又名: 手足情未了(港) / 手足情深
IMDb: tt0095953
豆瓣评分
引用
8.7
386262人评价
5星
47.1%
4星
43.5%
3星
8.9%
2星
0.4%
1星
0.1%
好于 97% 剧情片
想看 看过
评价:
推荐

## 雨人的剧情简介 · · · · · ·

查理（汤姆·克鲁斯 Tom Cruise 饰）父亲去世，留下了300万美元的遗产。然而令他意外的是，遗产全部给了一个他不认识的哥哥雷蒙（达斯汀·霍夫曼 Dustin Hoffman 饰）。雷蒙的名字查理从没听过，这个事件让他气愤不已。他决定前去寻找哥哥。谁知雷蒙的住处就在一个精神病院里，原来他自幼患有自闭症，母亲去世后就被送到精神病院治疗。查理心中有了算计，他把雷蒙带出精神病院，企图骗他出让遗产。
雷蒙的生活习惯奇异，活在自己的幻想世界里，有很多离奇古怪的行为。并且，查理在共处中发现了雷蒙惊人的记忆能力，他试着利用哥哥过目不忘的本领去赌场上试一下身手，赢得了一大笔奖金，使查理足以摆脱穷困生活。而令查理收获更大的是，他还获得了慢慢升温的亲情，这种手足情远远胜过了他原先图谋的300万的遗产。 ©豆瓣

## 雨人的演职员 · · · · · · ( 全部 28 )

- 巴瑞·莱文森 导演
- 达斯汀·霍夫曼 饰 Raymond Babbitt
- 汤姆·克鲁斯 饰 Charlie Babbitt
- 瓦莱丽亚·戈利诺 饰 Susanna
- 邦尼·亨特 饰 Sally Dibbs
- 贝丝·格兰特 饰 Mother at Farm House

## 雨人的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片555 · 添加 )

## 雨人的获奖情况 · · · · · · ( 全部 )

- 第61届奥斯卡金像奖
- 最佳影片
- 马克·约翰逊

- 第39届柏林国际电影节
- 金熊奖 最佳影片
- 巴瑞·莱文森

- 第13届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  饮食男女

  一次别离

  岁月神偷

  我是山姆

  海边的曼彻斯特

  大鱼

  燃情岁月

  不一样的天空

  小偷家族

  喜宴

我要写短评

## 雨人的短评 · · · · · · ( 全部 64646 条 )

热门 / 最新 / 好友

### 1522 有用 露娜peace 看过 2006-06-12 10:03:02

ray……听上去很像rain，愚顿的哥哥曾经对心爱的弟弟说，我是rain man。直到生命进行到成人的阶段，弟弟才突然想起，童年时，他的生活中曾经有一个爱他疼他的雨人……

### 980 有用 Q。 看过 2011-07-08 23:18:39

年轻帅气的阿汤哥，让人眼前一亮的霍夫曼。故事简简单单，配乐大气，并没有特别煽情的段落，不刻意讨好，不哗众取宠，让人看起来十分舒服，让人感动在不知不觉中。★★★☆

### 633 有用 Ex 看过 2006-07-23 14:47:48

如果影片可以不那么拖沓.我会把它列为四星.结尾很感人.中间有很多情节可以砍掉.

### 1579 有用 孔小洞 看过 2010-04-19 20:52:26

我可不可以把它看成一部公路片，某种程度。

### 744 有用 薇羅尼卡 看过 2006-03-29 16:05:40

原来童年最好的伙伴竟然是最亲密的兄长

> 更多短评 64646条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 雨人的影评 · · · · · · ( 全部 795 条 )

热门 / 最新 / 好友
吉小娜 2006-01-24 00:40:03

## 亲爱的雨人

看完了《雨人》，惊觉亲情的魅力竟是如此细腻而又震撼人心。当片子到了最后，面对即将来临的离别，弟弟坦白出心中的不舍，憨憨傻傻的雨人竟然主动让两人的额头相贴。那个镜头缓缓地延续了将近一分钟，两人心灵的沟通在一刹那间迸发。虽然电影没有进行倒叙，然而之前二人相处的... (展开)
1959 136 195回应 收起
隔壁LEO在唱歌 2006-11-01 14:18:15

## 《雨人》中的父子情----一次不完全观影的片面感受

这是一次不完全观影的片面感受。我并没有从头到尾看完这部电影，原因很尴尬，下面会说到。在这个前提下，我的感受也是片面的，很可能是错误的。管中窥豹的我本没有资格评论这部片子，但既然有了感受，便如同鲠骨在喉，不... (展开)
879 115 138回应 收起
明天小镇 2006-06-19 22:00:56

## 雨人是真正的诗人---看《雨人》

《雨人》Rain Man 导演 巴里•莱温森 （Barry Levinson） 主演 达斯汀•霍夫曼（Dustin Hoffman） 瓦莱里亚•戈里诺（Valeria Golino） 影片获奖情况 第61届奥斯卡金像奖 最佳影片 最佳男主角 最佳导演 最佳改编剧本 这部电影展示给我们很多美丽的自然风光。... (展开)
393 39 31回应 收起
blueloo 2008-09-28 11:52:55

## 可是他懂得爱

这篇影评可能有剧透

有这样一种故事，它是高脚杯里绯红色的果汁鸡尾酒，喝下去是带着苦涩的甜蜜，它是精致的抹茶蛋糕上那一小片醉人的绿，清新而令人流连，它还是刚煎好的牛排冒出的热气，温暖又有点刺痛人。雨人就是这样的故事，散发着种种微妙的情感，需要我们用心品尝。 这是一部以亲... (展开)
235 18 24回应 收起
小披风 2019-02-26 23:48:51

## 实名反对第二条热评，关于父亲为啥留车给男主，完全是胡说八道

这篇影评可能有剧透

热评第二的楼主，大部分见解都是有误的，可见真的在一心二用看球赛，居然还有那么多人回复。 1、雨人幻想。 弟弟小时候和哥哥一起生活过，但那时候太小了，约莫只有三～四岁（参见两哥弟合照），因此记忆不清楚。 哥哥名字叫雷蒙，弟弟年幼误读成“rain man” 即“雨人”。 哥... (展开)
244 1 23回应 收起
苏小蒙 2006-03-07 06:00:15

## 雨人

是不是每个人小时候，都会想象有一个耐心的哥哥，会倾听，会保护，会唱歌。 是不是一天一天长大的时候，我们就将童年的他们永远的留在了身后。 是不是当棱角一天天柔和起来的时候，心却一天天变得坚韧， 于是固执的尘封起那些孤单的记忆，深怕，想起，会心痛。 有一种人... (展开)
163 27 40回应 收起
谋杀游戏机 2011-10-09 20:54:18

## 伟岸“雨人”——记达斯汀·霍夫曼

review by Hal Hinson 翻译/何小沁 波林·卡尔为《雨人》写的影评的第一句话是，“《雨人》好比达斯汀·霍夫曼用两小时十一分钟的时间在钢琴上弹出一个音符”。尽管自影片公映以来他的表演一再被效仿，霍夫曼不可否认地表现出众，别具一格。卡尔似乎并不认为一根筋的雷蒙德（... (展开)
91 8 12回应 收起
不要不开心哦 2017-05-13 15:18:09

## 雨人

这篇影评可能有剧透

如果你的生命中没有母亲，刚刚失去父亲，却突然多出一个哥哥，会有怎样的反应？爱他，对吧。但如果父亲将所有遗产都留给他，而他却是一个精神有问题连生活都无法自理的人，尤其是当你正陷入财政危机的时候，你又会怎样反应？该狂怒了吧。年轻的弟弟就是这样怀着一腔愤懑，把哥... (展开)
23 0回应 收起
泡芙味的草莓 2017-06-11 20:12:00

## 雨人

该片不仅仅是一部公路电影，也是一部家庭伦理故事。虽然Charlie是因为遗产而带走哥哥的，但是他心中是有这个陌生的亲人，也有这个不尽人意的家。而不善表达的Raymond对于弟弟的爱，更是从未有变过。随着与祖屋与家乡的距离，愈来愈远，两人的心却渐渐的接近。影片最后，两个原... (展开)
20 1 1回应 收起

> 更多影评 795篇

添加新讨论

## 讨论区 · · · · · ·

想不明白查理女票为什么亲吻哥哥？ | 来自stangwhat | 41 回应 | 2022-11-24 19:42:00
为什么理查的GF要在电梯里吻Rain？ | 来自塗尔干 | 44 回应 | 2022-11-18 14:40:58
雨人很感人，但是拿奥斯卡尚欠说服力。 | 来自易 | 21 回应 | 2022-11-13 23:02:23
无感 | 来自刘锐 | 1 回应 | 2022-11-02 05:45:09
火车上的告别“one for bad，two for good” | 来自热带鱼 | 1 回应 | 2022-10-19 13:01:10

> 去这部影片的讨论区（全部146条）

## 关于《雨人》的问题 · · · · · · ( 全部23个 )

- 结尾汤姆克鲁斯说押2是对的是什么意思？ 8人回答
- 在自助洗衣店的时候，雷蒙为什么使劲盯着洗衣机里面的红色衣服？ 5人回答

> 全部23个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 心理学电影(一句话剧透,不喜勿入) (何学卿)
- 【励志电影】 (影志)
- {北美电影票房总排行} (荔枝超人)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  3分钟前 想看
- cassandra
  7分钟前 看过
- 荔枝hy
  9分钟前 看过

609970人看过 / 266450人想看

订阅雨人的评论:
feed: rss 2.0